summaryrefslogtreecommitdiffstats
path: root/ash/system
diff options
context:
space:
mode:
Diffstat (limited to 'ash/system')
-rw-r--r--ash/system/chromeos/supervised/tray_supervised_user.cc (renamed from ash/system/chromeos/managed/tray_locally_managed_user.cc)34
-rw-r--r--ash/system/chromeos/supervised/tray_supervised_user.h (renamed from ash/system/chromeos/managed/tray_locally_managed_user.h)18
-rw-r--r--ash/system/chromeos/supervised/tray_supervised_user_unittest.cc (renamed from ash/system/chromeos/managed/tray_locally_managed_user_unittest.cc)38
-rw-r--r--ash/system/chromeos/tray_display.cc2
-rw-r--r--ash/system/system_notifier.cc16
-rw-r--r--ash/system/system_notifier.h2
-rw-r--r--ash/system/tray/default_system_tray_delegate.cc8
-rw-r--r--ash/system/tray/default_system_tray_delegate.h8
-rw-r--r--ash/system/tray/system_tray.cc4
-rw-r--r--ash/system/tray/system_tray_delegate.h18
-rw-r--r--ash/system/user/login_status.h2
-rw-r--r--ash/system/user/tray_user.cc4
-rw-r--r--ash/system/user/user_card_view.cc2
-rw-r--r--ash/system/user/user_view.cc2
14 files changed, 81 insertions, 77 deletions
diff --git a/ash/system/chromeos/managed/tray_locally_managed_user.cc b/ash/system/chromeos/supervised/tray_supervised_user.cc
index 7c22016..2d0012f 100644
--- a/ash/system/chromeos/managed/tray_locally_managed_user.cc
+++ b/ash/system/chromeos/supervised/tray_supervised_user.cc
@@ -1,8 +1,8 @@
-// Copyright (c) 2012 The Chromium Authors. All rights reserved.
+// Copyright 2014 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#include "ash/system/chromeos/managed/tray_locally_managed_user.h"
+#include "ash/system/chromeos/supervised/tray_supervised_user.h"
#include "ash/shell.h"
#include "ash/system/chromeos/label_tray_view.h"
@@ -22,21 +22,21 @@ using message_center::Notification;
namespace ash {
-const char TrayLocallyManagedUser::kNotificationId[] =
+const char TraySupervisedUser::kNotificationId[] =
"chrome://user/locally-managed";
-TrayLocallyManagedUser::TrayLocallyManagedUser(SystemTray* system_tray)
+TraySupervisedUser::TraySupervisedUser(SystemTray* system_tray)
: SystemTrayItem(system_tray),
tray_view_(NULL),
status_(ash::user::LOGGED_IN_NONE) {
}
-TrayLocallyManagedUser::~TrayLocallyManagedUser() {
+TraySupervisedUser::~TraySupervisedUser() {
}
-void TrayLocallyManagedUser::UpdateMessage() {
+void TraySupervisedUser::UpdateMessage() {
base::string16 message = Shell::GetInstance()->system_tray_delegate()->
- GetLocallyManagedUserMessage();
+ GetSupervisedUserMessage();
if (tray_view_)
tray_view_->SetMessage(message);
if (message_center::MessageCenter::Get()->FindVisibleNotificationById(
@@ -44,10 +44,10 @@ void TrayLocallyManagedUser::UpdateMessage() {
CreateOrUpdateNotification(message);
}
-views::View* TrayLocallyManagedUser::CreateDefaultView(
+views::View* TraySupervisedUser::CreateDefaultView(
user::LoginStatus status) {
CHECK(tray_view_ == NULL);
- if (status != ash::user::LOGGED_IN_LOCALLY_MANAGED)
+ if (status != ash::user::LOGGED_IN_SUPERVISED)
return NULL;
tray_view_ = new LabelTrayView(this, IDR_AURA_UBER_TRAY_MANAGED_USER);
@@ -55,27 +55,27 @@ views::View* TrayLocallyManagedUser::CreateDefaultView(
return tray_view_;
}
-void TrayLocallyManagedUser::DestroyDefaultView() {
+void TraySupervisedUser::DestroyDefaultView() {
tray_view_ = NULL;
}
-void TrayLocallyManagedUser::OnViewClicked(views::View* sender) {
- Shell::GetInstance()->system_tray_delegate()->ShowLocallyManagedUserInfo();
+void TraySupervisedUser::OnViewClicked(views::View* sender) {
+ Shell::GetInstance()->system_tray_delegate()->ShowSupervisedUserInfo();
}
-void TrayLocallyManagedUser::UpdateAfterLoginStatusChange(
+void TraySupervisedUser::UpdateAfterLoginStatusChange(
user::LoginStatus status) {
if (status == status_)
return;
- if (status == ash::user::LOGGED_IN_LOCALLY_MANAGED &&
+ if (status == ash::user::LOGGED_IN_SUPERVISED &&
status_ != ash::user::LOGGED_IN_LOCKED) {
SystemTrayDelegate* delegate = Shell::GetInstance()->system_tray_delegate();
- CreateOrUpdateNotification(delegate->GetLocallyManagedUserMessage());
+ CreateOrUpdateNotification(delegate->GetSupervisedUserMessage());
}
status_ = status;
}
-void TrayLocallyManagedUser::CreateOrUpdateNotification(
+void TraySupervisedUser::CreateOrUpdateNotification(
const base::string16& new_message) {
ui::ResourceBundle& bundle = ui::ResourceBundle::GetSharedInstance();
scoped_ptr<Notification> notification(
@@ -84,7 +84,7 @@ void TrayLocallyManagedUser::CreateOrUpdateNotification(
base::string16() /* no title */,
new_message,
bundle.GetImageNamed(IDR_AURA_UBER_TRAY_MANAGED_USER),
- system_notifier::kNotifierLocallyManagedUser,
+ system_notifier::kNotifierSupervisedUser,
base::Closure() /* null callback */));
message_center::MessageCenter::Get()->AddNotification(notification.Pass());
}
diff --git a/ash/system/chromeos/managed/tray_locally_managed_user.h b/ash/system/chromeos/supervised/tray_supervised_user.h
index 666530b..dbad222 100644
--- a/ash/system/chromeos/managed/tray_locally_managed_user.h
+++ b/ash/system/chromeos/supervised/tray_supervised_user.h
@@ -1,9 +1,9 @@
-// Copyright (c) 2012 The Chromium Authors. All rights reserved.
+// Copyright 2014 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef ASH_SYSTEM_CHROMEOS_LOCALLY_MANAGED_TRAY_LOCALLY_MANAGED_USER_H
-#define ASH_SYSTEM_CHROMEOS_LOCALLY_MANAGED_TRAY_LOCALLY_MANAGED_USER_H
+#ifndef ASH_SYSTEM_CHROMEOS_SUPERVISED_TRAY_SUPERVISED_USER_H
+#define ASH_SYSTEM_CHROMEOS_SUPERVISED_TRAY_SUPERVISED_USER_H
#include "ash/ash_export.h"
#include "ash/system/tray/system_tray_item.h"
@@ -14,11 +14,11 @@ namespace ash {
class LabelTrayView;
class SystemTray;
-class ASH_EXPORT TrayLocallyManagedUser : public SystemTrayItem,
+class ASH_EXPORT TraySupervisedUser : public SystemTrayItem,
public ViewClickListener {
public:
- explicit TrayLocallyManagedUser(SystemTray* system_tray);
- virtual ~TrayLocallyManagedUser();
+ explicit TraySupervisedUser(SystemTray* system_tray);
+ virtual ~TraySupervisedUser();
// If message is not empty updates content of default view, otherwise hides
// tray items.
@@ -33,7 +33,7 @@ class ASH_EXPORT TrayLocallyManagedUser : public SystemTrayItem,
virtual void OnViewClicked(views::View* sender) OVERRIDE;
private:
- friend class TrayLocallyManagedUserTest;
+ friend class TraySupervisedUserTest;
static const char kNotificationId[];
@@ -43,9 +43,9 @@ class ASH_EXPORT TrayLocallyManagedUser : public SystemTrayItem,
// Previous login status to avoid showing notification upon unlock.
user::LoginStatus status_;
- DISALLOW_COPY_AND_ASSIGN(TrayLocallyManagedUser);
+ DISALLOW_COPY_AND_ASSIGN(TraySupervisedUser);
};
} // namespace ash
-#endif // ASH_SYSTEM_CHROMEOS_LOCALLY_MANAGED_TRAY_LOCALLY_MANAGED_USER_H
+#endif // ASH_SYSTEM_CHROMEOS_SUPERVISED_TRAY_SUPERVISED_USER_H
diff --git a/ash/system/chromeos/tray_display.cc b/ash/system/chromeos/tray_display.cc
index 1e02e30..d1fca84 100644
--- a/ash/system/chromeos/tray_display.cc
+++ b/ash/system/chromeos/tray_display.cc
@@ -120,7 +120,7 @@ void OpenSettings() {
case user::LOGGED_IN_GUEST:
case user::LOGGED_IN_RETAIL_MODE:
case user::LOGGED_IN_PUBLIC:
- case user::LOGGED_IN_LOCALLY_MANAGED:
+ case user::LOGGED_IN_SUPERVISED:
case user::LOGGED_IN_KIOSK_APP:
Shell::GetInstance()->system_tray_delegate()->ShowDisplaySettings();
}
diff --git a/ash/system/system_notifier.cc b/ash/system/system_notifier.cc
index 7669186..2910862 100644
--- a/ash/system/system_notifier.cc
+++ b/ash/system/system_notifier.cc
@@ -18,25 +18,29 @@ const char* kAlwaysShownNotifierIds[] = {
kNotifierDisplayError,
kNotifierNetworkError,
kNotifierPower,
+ // Note: Order doesn't matter here, so keep this in alphabetic order, don't
+ // just add your stuff at the end!
NULL
};
const char* kAshSystemNotifiers[] = {
+ kNotifierBluetooth,
kNotifierDisplay,
- kNotifierDisplayResolutionChange,
kNotifierDisplayError,
+ kNotifierDisplayResolutionChange,
kNotifierLocale,
- kNotifierLocallyManagedUser,
kNotifierMultiProfileFirstRun,
kNotifierNetwork,
kNotifierNetworkError,
kNotifierNetworkPortalDetector,
+ kNotifierPower,
kNotifierScreenshot,
kNotifierScreenCapture,
kNotifierScreenShare,
kNotifierSessionLengthTimeout,
- kNotifierPower,
- kNotifierBluetooth,
+ kNotifierSupervisedUser,
+ // Note: Order doesn't matter here, so keep this in alphabetic order, don't
+ // just add your stuff at the end!
NULL
};
@@ -56,10 +60,9 @@ bool MatchSystemNotifierId(const message_center::NotifierId& notifier_id,
const char kNotifierBluetooth[] = "ash.bluetooth";
const char kNotifierDisplay[] = "ash.display";
-const char kNotifierDisplayResolutionChange[] = "ash.display.resolution-change";
const char kNotifierDisplayError[] = "ash.display.error";
+const char kNotifierDisplayResolutionChange[] = "ash.display.resolution-change";
const char kNotifierLocale[] = "ash.locale";
-const char kNotifierLocallyManagedUser[] = "ash.locally-managed-user";
const char kNotifierMultiProfileFirstRun[] = "ash.multi-profile.first-run";
const char kNotifierNetwork[] = "ash.network";
const char kNotifierNetworkError[] = "ash.network.error";
@@ -69,6 +72,7 @@ const char kNotifierScreenshot[] = "ash.screenshot";
const char kNotifierScreenCapture[] = "ash.screen-capture";
const char kNotifierScreenShare[] = "ash.screen-share";
const char kNotifierSessionLengthTimeout[] = "ash.session-length-timeout";
+const char kNotifierSupervisedUser[] = "ash.locally-managed-user";
bool ShouldAlwaysShowPopups(const message_center::NotifierId& notifier_id) {
return MatchSystemNotifierId(notifier_id, kAlwaysShownNotifierIds);
diff --git a/ash/system/system_notifier.h b/ash/system/system_notifier.h
index 0d4b6c7..db741ec 100644
--- a/ash/system/system_notifier.h
+++ b/ash/system/system_notifier.h
@@ -19,7 +19,6 @@ ASH_EXPORT extern const char kNotifierDisplay[];
ASH_EXPORT extern const char kNotifierDisplayResolutionChange[];
ASH_EXPORT extern const char kNotifierDisplayError[];
ASH_EXPORT extern const char kNotifierLocale[];
-ASH_EXPORT extern const char kNotifierLocallyManagedUser[];
ASH_EXPORT extern const char kNotifierMultiProfileFirstRun[];
ASH_EXPORT extern const char kNotifierNetwork[];
ASH_EXPORT extern const char kNotifierNetworkError[];
@@ -29,6 +28,7 @@ ASH_EXPORT extern const char kNotifierScreenshot[];
ASH_EXPORT extern const char kNotifierScreenCapture[];
ASH_EXPORT extern const char kNotifierScreenShare[];
ASH_EXPORT extern const char kNotifierSessionLengthTimeout[];
+ASH_EXPORT extern const char kNotifierSupervisedUser[];
// Returns true if notifications from |notifier_id| should always appear as
// popups. "Always appear" means the popups should appear even in login screen,
diff --git a/ash/system/tray/default_system_tray_delegate.cc b/ash/system/tray/default_system_tray_delegate.cc
index eae6bd3..839575bef 100644
--- a/ash/system/tray/default_system_tray_delegate.cc
+++ b/ash/system/tray/default_system_tray_delegate.cc
@@ -71,17 +71,17 @@ const base::string16 DefaultSystemTrayDelegate::GetEnterpriseMessage() const {
}
const std::string
-DefaultSystemTrayDelegate::GetLocallyManagedUserManager() const {
+DefaultSystemTrayDelegate::GetSupervisedUserManager() const {
return std::string();
}
const base::string16
-DefaultSystemTrayDelegate::GetLocallyManagedUserManagerName()
+DefaultSystemTrayDelegate::GetSupervisedUserManagerName()
const {
return base::string16();
}
-const base::string16 DefaultSystemTrayDelegate::GetLocallyManagedUserMessage()
+const base::string16 DefaultSystemTrayDelegate::GetSupervisedUserMessage()
const {
return base::string16();
}
@@ -145,7 +145,7 @@ void DefaultSystemTrayDelegate::ShowPublicAccountInfo() {
void DefaultSystemTrayDelegate::ShowEnterpriseInfo() {
}
-void DefaultSystemTrayDelegate::ShowLocallyManagedUserInfo() {
+void DefaultSystemTrayDelegate::ShowSupervisedUserInfo() {
}
void DefaultSystemTrayDelegate::ShowUserLogin() {
diff --git a/ash/system/tray/default_system_tray_delegate.h b/ash/system/tray/default_system_tray_delegate.h
index 7586932..84594bd 100644
--- a/ash/system/tray/default_system_tray_delegate.h
+++ b/ash/system/tray/default_system_tray_delegate.h
@@ -25,10 +25,10 @@ class ASH_EXPORT DefaultSystemTrayDelegate : public SystemTrayDelegate {
virtual void ChangeProfilePicture() OVERRIDE;
virtual const std::string GetEnterpriseDomain() const OVERRIDE;
virtual const base::string16 GetEnterpriseMessage() const OVERRIDE;
- virtual const std::string GetLocallyManagedUserManager() const OVERRIDE;
- virtual const base::string16 GetLocallyManagedUserManagerName() const
+ virtual const std::string GetSupervisedUserManager() const OVERRIDE;
+ virtual const base::string16 GetSupervisedUserManagerName() const
OVERRIDE;
- virtual const base::string16 GetLocallyManagedUserMessage() const OVERRIDE;
+ virtual const base::string16 GetSupervisedUserMessage() const OVERRIDE;
virtual bool SystemShouldUpgrade() const OVERRIDE;
virtual base::HourClockType GetHourClockType() const OVERRIDE;
virtual void ShowSettings() OVERRIDE;
@@ -47,7 +47,7 @@ class ASH_EXPORT DefaultSystemTrayDelegate : public SystemTrayDelegate {
virtual void ShowAccessibilitySettings() OVERRIDE;
virtual void ShowPublicAccountInfo() OVERRIDE;
virtual void ShowEnterpriseInfo() OVERRIDE;
- virtual void ShowLocallyManagedUserInfo() OVERRIDE;
+ virtual void ShowSupervisedUserInfo() OVERRIDE;
virtual void ShowUserLogin() OVERRIDE;
virtual bool ShowSpringChargerReplacementDialog() OVERRIDE;
virtual bool IsSpringChargerReplacementDialogVisible() OVERRIDE;
diff --git a/ash/system/tray/system_tray.cc b/ash/system/tray/system_tray.cc
index 5c6af2c..b4ba58e 100644
--- a/ash/system/tray/system_tray.cc
+++ b/ash/system/tray/system_tray.cc
@@ -47,7 +47,6 @@
#include "ash/system/chromeos/audio/tray_audio_chromeos.h"
#include "ash/system/chromeos/brightness/tray_brightness.h"
#include "ash/system/chromeos/enterprise/tray_enterprise.h"
-#include "ash/system/chromeos/managed/tray_locally_managed_user.h"
#include "ash/system/chromeos/network/tray_network.h"
#include "ash/system/chromeos/network/tray_sms.h"
#include "ash/system/chromeos/network/tray_vpn.h"
@@ -57,6 +56,7 @@
#include "ash/system/chromeos/screen_security/screen_share_tray_item.h"
#include "ash/system/chromeos/session/tray_session_length_limit.h"
#include "ash/system/chromeos/settings/tray_settings.h"
+#include "ash/system/chromeos/supervised/tray_supervised_user.h"
#include "ash/system/chromeos/tray_caps_lock.h"
#include "ash/system/chromeos/tray_display.h"
#include "ash/system/chromeos/tray_tracing.h"
@@ -173,7 +173,7 @@ void SystemTray::CreateItems(SystemTrayDelegate* delegate) {
#if defined(OS_CHROMEOS)
AddTrayItem(new TraySessionLengthLimit(this));
AddTrayItem(new TrayEnterprise(this));
- AddTrayItem(new TrayLocallyManagedUser(this));
+ AddTrayItem(new TraySupervisedUser(this));
AddTrayItem(new TrayIME(this));
AddTrayItem(tray_accessibility_);
AddTrayItem(new TrayTracing(this));
diff --git a/ash/system/user/tray_user.cc b/ash/system/user/tray_user.cc
index 91dce33..1d26441 100644
--- a/ash/system/user/tray_user.cc
+++ b/ash/system/user/tray_user.cc
@@ -140,7 +140,7 @@ void TrayUser::UpdateAfterLoginStatusChange(user::LoginStatus status) {
case user::LOGGED_IN_PUBLIC:
need_avatar = true;
break;
- case user::LOGGED_IN_LOCALLY_MANAGED:
+ case user::LOGGED_IN_SUPERVISED:
need_avatar = true;
need_label = true;
break;
@@ -171,7 +171,7 @@ void TrayUser::UpdateAfterLoginStatusChange(user::LoginStatus status) {
}
}
- if (status == user::LOGGED_IN_LOCALLY_MANAGED) {
+ if (status == user::LOGGED_IN_SUPERVISED) {
label_->SetText(
l10n_util::GetStringUTF16(IDS_ASH_STATUS_TRAY_LOCALLY_MANAGED_LABEL));
} else if (status == user::LOGGED_IN_GUEST) {
diff --git a/ash/system/user/user_card_view.cc b/ash/system/user/user_card_view.cc
index 84d52b6..8549846 100644
--- a/ash/system/user/user_card_view.cc
+++ b/ash/system/user/user_card_view.cc
@@ -395,7 +395,7 @@ void UserCardView::AddUserContent(user::LoginStatus login_status,
if (login_status != user::LOGGED_IN_GUEST &&
(multiprofile_index || !IsMultiAccountSupportedAndUserActive())) {
base::string16 user_email_string =
- login_status == user::LOGGED_IN_LOCALLY_MANAGED
+ login_status == user::LOGGED_IN_SUPERVISED
? l10n_util::GetStringUTF16(
IDS_ASH_STATUS_TRAY_LOCALLY_MANAGED_LABEL)
: base::UTF8ToUTF16(
diff --git a/ash/system/user/user_view.cc b/ash/system/user/user_view.cc
index 0d66217..f3646a7 100644
--- a/ash/system/user/user_view.cc
+++ b/ash/system/user/user_view.cc
@@ -451,7 +451,7 @@ void UserView::AddUserCard(user::LoginStatus login) {
is_user_card_button_ = true;
}
AddChildViewAt(user_card_view_, 0);
- // Card for locally managed user can consume more space than currently
+ // Card for supervised user can consume more space than currently
// available. In that case we should increase system bubble's width.
if (login == user::LOGGED_IN_PUBLIC)
bubble_view->SetWidth(GetPreferredSize().width());
diff --git a/ash/system/chromeos/managed/tray_locally_managed_user_unittest.cc b/ash/system/chromeos/supervised/tray_supervised_user_unittest.cc
index ca5af22..cc65056 100644
--- a/ash/system/chromeos/managed/tray_locally_managed_user_unittest.cc
+++ b/ash/system/chromeos/supervised/tray_supervised_user_unittest.cc
@@ -1,8 +1,8 @@
-// Copyright 2013 The Chromium Authors. All rights reserved.
+// Copyright 2014 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#include "ash/system/chromeos/managed/tray_locally_managed_user.h"
+#include "ash/system/chromeos/supervised/tray_supervised_user.h"
#include "ash/shell.h"
#include "ash/system/user/login_status.h"
@@ -17,57 +17,57 @@ using message_center::NotificationList;
namespace ash {
-class TrayLocallyManagedUserTest : public test::AshTestBase {
+class TraySupervisedUserTest : public test::AshTestBase {
public:
- TrayLocallyManagedUserTest() {}
- virtual ~TrayLocallyManagedUserTest() {}
+ TraySupervisedUserTest() {}
+ virtual ~TraySupervisedUserTest() {}
protected:
message_center::Notification* GetPopup();
private:
- DISALLOW_COPY_AND_ASSIGN(TrayLocallyManagedUserTest);
+ DISALLOW_COPY_AND_ASSIGN(TraySupervisedUserTest);
};
-message_center::Notification* TrayLocallyManagedUserTest::GetPopup() {
+message_center::Notification* TraySupervisedUserTest::GetPopup() {
NotificationList::PopupNotifications popups =
message_center::MessageCenter::Get()->GetPopupNotifications();
for (NotificationList::PopupNotifications::const_iterator iter =
popups.begin(); iter != popups.end(); ++iter) {
- if ((*iter)->id() == TrayLocallyManagedUser::kNotificationId)
+ if ((*iter)->id() == TraySupervisedUser::kNotificationId)
return *iter;
}
return NULL;
}
-class TrayLocallyManagedUserInitialTest : public TrayLocallyManagedUserTest {
+class TraySupervisedUserInitialTest : public TraySupervisedUserTest {
public:
- TrayLocallyManagedUserInitialTest() {}
- virtual ~TrayLocallyManagedUserInitialTest() {}
+ TraySupervisedUserInitialTest() {}
+ virtual ~TraySupervisedUserInitialTest() {}
virtual void SetUp() OVERRIDE;
virtual void TearDown() OVERRIDE;
private:
- DISALLOW_COPY_AND_ASSIGN(TrayLocallyManagedUserInitialTest);
+ DISALLOW_COPY_AND_ASSIGN(TraySupervisedUserInitialTest);
};
-void TrayLocallyManagedUserInitialTest::SetUp() {
+void TraySupervisedUserInitialTest::SetUp() {
test::TestSystemTrayDelegate::SetInitialLoginStatus(
- user::LOGGED_IN_LOCALLY_MANAGED);
+ user::LOGGED_IN_SUPERVISED);
test::AshTestBase::SetUp();
}
-void TrayLocallyManagedUserInitialTest::TearDown() {
+void TraySupervisedUserInitialTest::TearDown() {
test::AshTestBase::TearDown();
// SetInitialLoginStatus() is reset in AshTestHelper::TearDown().
}
-TEST_F(TrayLocallyManagedUserTest, LocallyManagedUserHasNotification) {
+TEST_F(TraySupervisedUserTest, SupervisedUserHasNotification) {
test::TestSystemTrayDelegate* delegate =
static_cast<test::TestSystemTrayDelegate*>(
ash::Shell::GetInstance()->system_tray_delegate());
- delegate->SetLoginStatus(user::LOGGED_IN_LOCALLY_MANAGED);
+ delegate->SetLoginStatus(user::LOGGED_IN_SUPERVISED);
message_center::Notification* notification = GetPopup();
ASSERT_NE(static_cast<message_center::Notification*>(NULL), notification);
@@ -75,8 +75,8 @@ TEST_F(TrayLocallyManagedUserTest, LocallyManagedUserHasNotification) {
notification->rich_notification_data().priority);
}
-TEST_F(TrayLocallyManagedUserInitialTest, LocallyManagedUserNoCrash) {
- // Initial login status is already LOCALLY_MANAGED, which should create
+TEST_F(TraySupervisedUserInitialTest, SupervisedUserNoCrash) {
+ // Initial login status is already SUPERVISED, which should create
// the notification and should not cause crashes.
message_center::Notification* notification = GetPopup();
ASSERT_NE(static_cast<message_center::Notification*>(NULL), notification);
diff --git a/ash/system/tray/system_tray_delegate.h b/ash/system/tray/system_tray_delegate.h
index 73fd0ca..dffa9f1 100644
--- a/ash/system/tray/system_tray_delegate.h
+++ b/ash/system/tray/system_tray_delegate.h
@@ -140,15 +140,15 @@ class ASH_EXPORT SystemTrayDelegate {
// Returns notification for enterprise enrolled devices.
virtual const base::string16 GetEnterpriseMessage() const = 0;
- // Returns the display email of user that manages current
- // locally managed user.
- virtual const std::string GetLocallyManagedUserManager() const = 0;
+ // Returns the display email of the user that manages the current supervised
+ // user.
+ virtual const std::string GetSupervisedUserManager() const = 0;
- // Returns the name of user that manages current locally managed user.
- virtual const base::string16 GetLocallyManagedUserManagerName() const = 0;
+ // Returns the name of the user that manages the current supervised user.
+ virtual const base::string16 GetSupervisedUserManagerName() const = 0;
- // Returns notification for locally managed users.
- virtual const base::string16 GetLocallyManagedUserMessage() const = 0;
+ // Returns the notification for supervised users.
+ virtual const base::string16 GetSupervisedUserMessage() const = 0;
// Returns whether a system upgrade is available.
virtual bool SystemShouldUpgrade() const = 0;
@@ -206,8 +206,8 @@ class ASH_EXPORT SystemTrayDelegate {
// Shows information about enterprise enrolled devices.
virtual void ShowEnterpriseInfo() = 0;
- // Shows information about locally managed users.
- virtual void ShowLocallyManagedUserInfo() = 0;
+ // Shows information about supervised users.
+ virtual void ShowSupervisedUserInfo() = 0;
// Shows login UI to add other users to this session.
virtual void ShowUserLogin() = 0;
diff --git a/ash/system/user/login_status.h b/ash/system/user/login_status.h
index d08a160..97e6859 100644
--- a/ash/system/user/login_status.h
+++ b/ash/system/user/login_status.h
@@ -18,7 +18,7 @@ enum LoginStatus {
LOGGED_IN_GUEST, // A guest is logged in (i.e. incognito)
LOGGED_IN_RETAIL_MODE, // Is in retail mode
LOGGED_IN_PUBLIC, // A public account is logged in
- LOGGED_IN_LOCALLY_MANAGED, // A locally managed user is logged in
+ LOGGED_IN_SUPERVISED, // A supervised user is logged in
LOGGED_IN_KIOSK_APP // Is in kiosk app mode
};